跳到主要内容

Video

搜索

结构体 Video 

源代码
pub struct Video(pub Encoder);

Tuple Fields

0: Encoder

实现

源代码

impl Video

源代码

pub fn open(self) -> Result<Encoder, Error>

源代码

pub fn open_as<E: Encoder>(self, codec: E) -> Result<Encoder, Error>

源代码

pub fn open_with(self, options: Dictionary<'_>) -> Result<Encoder, Error>

源代码

pub fn open_as_with<E: Encoder>( self, codec: E, options: Dictionary<'_>, ) -> Result<Encoder, Error>

源代码

pub fn set_width(&mut self, value: u32)

源代码

pub fn width(&self) -> u32

源代码

pub fn set_height(&mut self, value: u32)

源代码

pub fn height(&self) -> u32

源代码

pub fn set_gop(&mut self, value: u32)

源代码

pub fn set_format(&mut self, value: Pixel)

源代码

pub fn format(&self) -> Pixel

源代码

pub fn set_max_b_frames(&mut self, value: usize)

源代码

pub fn set_b_quant_factor(&mut self, value: f32)

源代码

pub fn set_b_quant_offset(&mut self, value: f32)

源代码

pub fn set_i_quant_factor(&mut self, value: f32)

源代码

pub fn set_i_quant_offset(&mut self, value: f32)

源代码

pub fn set_lumi_masking(&mut self, value: f32)

源代码

pub fn set_temporal_cplx_masking(&mut self, value: f32)

源代码

pub fn set_spatial_cplx_masking(&mut self, value: f32)

源代码

pub fn set_p_masking(&mut self, value: f32)

源代码

pub fn set_dark_masking(&mut self, value: f32)

源代码

pub fn set_aspect_ratio<R: Into<Rational>>(&mut self, value: R)

源代码

pub fn set_me_comparison(&mut self, value: Comparison)

源代码

pub fn set_me_sub_comparison(&mut self, value: Comparison)

源代码

pub fn set_mb_comparison(&mut self, value: Comparison)

源代码

pub fn set_ildct_comparison(&mut self, value: Comparison)

源代码

pub fn set_dia_size(&mut self, value: usize)

源代码

pub fn set_last_predictors(&mut self, value: usize)

源代码

pub fn set_me_pre_comparison(&mut self, value: Comparison)

源代码

pub fn set_pre_dia_size(&mut self, value: usize)

源代码

pub fn set_me_subpel_quality(&mut self, value: usize)

源代码

pub fn set_me_range(&mut self, value: usize)

源代码

pub fn set_mb_decision(&mut self, value: Decision)

源代码

pub fn set_mb_lmin(&mut self, value: i32)

源代码

pub fn set_mb_lmax(&mut self, value: i32)

源代码

pub fn set_intra_dc_precision(&mut self, value: u8)

源代码

pub fn set_qmin(&mut self, value: i32)

源代码

pub fn set_qmax(&mut self, value: i32)

源代码

pub fn set_global_quality(&mut self, value: i32)

源代码

pub fn set_colorspace(&mut self, value: Space)

源代码

pub fn colorspace(&self) -> Space

源代码

pub fn set_color_range(&mut self, value: Range)

源代码

pub fn color_range(&self) -> Range

Methods from Deref<Target = Super>

源代码

pub fn send_frame(&mut self, frame: &Frame) -> Result<(), Error>

源代码

pub fn send_eof(&mut self) -> Result<(), Error>

Sends a NULL packet to the encoder to signal end of stream and enter draining mode.

源代码

pub fn receive_packet<P: Mut>(&mut self, packet: &mut P) -> Result<(), Error>

源代码

pub fn set_bit_rate(&mut self, value: usize)

源代码

pub fn set_max_bit_rate(&mut self, value: usize)

源代码

pub fn set_tolerance(&mut self, value: usize)

源代码

pub fn set_quality(&mut self, value: usize)

源代码

pub fn set_compression(&mut self, value: Option<usize>)

Methods from Deref<Target = Context>

源代码

pub unsafe fn as_ptr(&self) -> *const AVCodecContext

源代码

pub unsafe fn as_mut_ptr(&mut self) -> *mut AVCodecContext

源代码

pub fn codec(&self) -> Option<Codec>

源代码

pub fn medium(&self) -> Type

源代码

pub fn set_flags(&mut self, value: Flags)

源代码

pub fn id(&self) -> Id

源代码

pub fn compliance(&mut self, value: Compliance)

源代码

pub fn debug(&mut self, value: Debug)

源代码

pub fn set_threading(&mut self, config: Config)

源代码

pub fn threading(&self) -> Config

源代码

pub fn set_parameters<P: Into<Parameters>>( &mut self, parameters: P, ) -> Result<(), Error>

源代码

pub fn time_base(&self) -> Rational

源代码

pub fn set_time_base<R: Into<Rational>>(&mut self, value: R)

源代码

pub fn frame_rate(&self) -> Rational

源代码

pub fn set_frame_rate<R: Into<Rational>>(&mut self, value: Option<R>)

trait 实现

源代码

impl AsMut<Context> for Video

源代码

fn as_mut(&mut self) -> &mut Context

Converts this type into a mutable reference of the (usually inferred) input type.
源代码

impl AsRef<Context> for Video

源代码

fn as_ref(&self) -> &Context

Converts this type into a shared reference of the (usually inferred) input type.
源代码

impl Deref for Video

源代码

type Target = Encoder

解引用之后得到的类型。
源代码

fn deref(&self) -> &<Self as Deref>::Target

解引用该值。
源代码

impl DerefMut for Video

源代码

fn deref_mut(&mut self) -> &mut <Self as Deref>::Target

Mutably dereferences the value.

自动 trait 实现



impl Freeze for Video



impl !RefUnwindSafe for Video



impl Send for Video



impl !Sync for Video



impl Unpin for Video



impl UnsafeUnpin for Video



impl !UnwindSafe for Video

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<P, T> Receiver for P
where P: Deref<Target = T> + ?Sized, T: ?Sized,

源代码

type Target = T

🔬This is a nightly-only experimental API. (arbitrary_self_types)
The target type on which the method may be called.
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。